@@ -121,6 +121,7 @@ setClass("TensorP_Basis", contains="Basis_obj", representation(Basis1="Basis",Ba
 #' @slot normalise_wts if \code{TRUE}, the rows of the incidence matrices \eqn{C_Z} and \eqn{C_P} are normalised to sum to 1, so that the mapping represents a weighted average; if false, no normalisation of the weights occurs (i.e., the mapping corresponds to a weighted sum)
 #' @slot fs_by_spatial_BAU if \code{TRUE}, then each BAU is associated with its own fine-scale variance parameter
 #' @slot obsidx indices of observed BAUs
+#' @slot simple_kriging_fixed logical indicating whether one wishes to commit to simple kriging at the fitting stage: If \code{TRUE}, model fitting is faster, but the option to conduct universal kriging at the prediction stage is removed 
 #' @seealso \code{\link{SRE}} for details on how to construct and fit SRE models.
 #' @references
 #' Zammit-Mangion, A. and Cressie, N. (2017). FRK: An R package for spatial and spatio-temporal prediction with large datasets. Journal of Statistical Software, 98(4), 1-48. doi:10.18637/jss.v098.i04.
@@ -160,4 +161,5 @@ setClass("SRE",representation(data="list",
                               include_fs = "logical", 
                               normalise_wts = "logical", 
                               fs_by_spatial_BAU = "logical", 
-                              obsidx = "numeric"))
+                              obsidx = "numeric", 
+                              simple_kriging_fixed = "logical"))
